@@ -54,6 +54,8 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_extra_provided_contracts', None),
             ('apic_extra_consumed_contracts', None),
             ('apic_policy_enforcement_pref', None),
+            ('apic_no_nat_cidrs', None),
+            ('apic_multi_ext_nets', None),
         ]
         create_ext = network_ext.CreateNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -86,6 +88,8 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             "--apic-extra-provided-contracts", 'pcontest1',
             "--apic-extra-consumed-contracts", 'contest1',
             "--apic-policy-enforcement-pref", 'enforced',
+            "--apic-no-nat-cidrs", '10.10.10.0/24',
+            "--apic-multi-ext-nets",
         ]
         verifylist = [
             ('name', self._network.name),
@@ -106,6 +110,8 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_extra_provided_contracts', 'pcontest1'),
             ('apic_extra_consumed_contracts', 'contest1'),
             ('apic_policy_enforcement_pref', 'enforced'),
+            ('apic_no_nat_cidrs', '10.10.10.0/24'),
+            ('apic_multi_ext_nets', True)
         ]
         create_ext = network_ext.CreateNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -133,6 +139,8 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             'apic:nested_domain_node_network_vlan': '4',
             'apic:nested_domain_service_vlan': '3',
             'apic:policy_enforcement_pref': 'enforced',
+            'apic:no_nat_cidrs': ['10.10.10.0/24'],
+            'apic:multi_ext_nets': True,
         })
 
     def test_create_empty_contracts(self):
@@ -165,6 +173,7 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             "--apic-distinguished-names", 'ExternalNetwork=test1',
             "--apic-nat-type", "",
             "--apic-external-cidrs", '20.20.20.0/8',
+            "--apic-no-nat-cidrs", '10.10.10.0/24',
         ]
         verifylist = [
             ('name', self._network.name),
@@ -172,6 +181,7 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_distinguished_names', [{'ExternalNetwork': 'test1'}]),
             ('apic_nat_type', ""),
             ('apic_external_cidrs', '20.20.20.0/8'),
+            ('apic_no_nat_cidrs', '10.10.10.0/24'),
         ]
         create_ext = network_ext.CreateNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -185,6 +195,7 @@ class TestNetworkCreate(test_network.TestNetwork, test_cli20.CLITestV20Base):
             'apic:distinguished_names': {"ExternalNetwork": "test1"},
             'apic:external_cidrs': ['20.20.20.0/8'],
             'apic:nat_type': '',
+            'apic:no_nat_cidrs': ['10.10.10.0/24'],
         })
 
 
@@ -219,6 +230,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_extra_provided_contracts', None),
             ('apic_extra_consumed_contracts', None),
             ('apic_policy_enforcement_pref', None),
+            ('apic_no_nat_cidrs', None),
         ]
         set_ext = network_ext.SetNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -245,6 +257,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             "--apic-extra-provided-contracts", 'pcontest1,pcontest11',
             "--apic-extra-consumed-contracts", 'contest1,contest11',
             "--apic-policy-enforcement-pref", 'enforced',
+            "--apic-no-nat-cidrs", '10.10.10.0/24',
         ]
         verifylist = [
             ('network', self._network.name),
@@ -262,6 +275,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_extra_provided_contracts', 'pcontest1,pcontest11'),
             ('apic_extra_consumed_contracts', 'contest1,contest11'),
             ('apic_policy_enforcement_pref', 'enforced'),
+            ('apic_no_nat_cidrs', '10.10.10.0/24'),
         ]
         set_ext = network_ext.SetNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -284,6 +298,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             'apic:nested_domain_node_network_vlan': '5',
             'apic:nested_domain_service_vlan': '4',
             'apic:policy_enforcement_pref': 'enforced',
+            'apic:no_nat_cidrs': ['10.10.10.0/24'],
         }
 
         self.network.update_network.assert_called_once_with(
@@ -295,6 +310,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             self._network.name,
             "--external",
             "--apic-no-external-cidrs",
+            "--no-apic-no-nat-cidrs",
         ]
         verifylist = [
             ('network', self._network.name),
@@ -313,6 +329,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
             ('apic_extra_provided_contracts', None),
             ('apic_extra_consumed_contracts', None),
             ('apic_policy_enforcement_pref', None),
+            ('no_apic_no_nat_cidrs', True),
         ]
         set_ext = network_ext.SetNetworkExtension(self.app)
         parsed_args = self.check_parser_ext(
@@ -322,6 +339,7 @@ class TestNetworkSet(test_network.TestNetwork, test_cli20.CLITestV20Base):
         attrs = {
             'router:external': True,
             'apic:external_cidrs': [],
+            'apic:no_nat_cidrs': [],
         }
 
         self.network.update_network.assert_called_once_with(
